Uses spatial comparison to determine which HUC polygons the locations fall into and returns the HUC identifier strings for those polygons.
If allData=TRUE, additional data is returned.
getHUC(lon, lat, SPDF, HUCs = NULL, allData = FALSE)vector of longitudes in decimal degrees
vector of latitudes in decimal degrees
spatial polygons dataset of HUCs
vector of Hydrologic Unit Codes
logical specifying whether a full dataframe should be returned
Vector of HUC identifiers.
getSpatialData