Uses spatial comparison to determine which HUC polygons the locations fall into and returns the HUC names for those polygons.
If allData=TRUE, additional data is returned.
getHUCName(lon, lat, dataset = "WBDHU10-ms", HUCs = NULL,
allData = FALSE)vector of longitudes in decimal degrees
vector of latitudes in decimal degrees
name of spatial dataset to use
vector of Hydrologic Unit Codes
logical specifying whether a full dataframe should be returned
Vector of HUC names.
getSpatialData