Extracts the the vector of unique polygon identifiers from SPDF.
This function is useful when writing code to aggregate data by polygon and
calculate per-polygon statistics. Each unique SpatialPolygonsDataFrame will have
a different set of data columns but each is guaranteed to have a column named
polygonID that uniquely identifies each polygon.
This allows us to write code that aggregates by polygon without having to know whether the polygons represent, countries, timezones or HUCs, etc.
getPolygonID(SPDF)spatial polygons datset of interest
Vector of polygon identifiers.