Learn R Programming

MazamaSpatialUtils (version 0.5.4)

convertUSCensusCongress: Convert US Congressional Disctricts Shapefile

Description

Returns a SpatialPolygonsDataFrame for US Congressional Districts for the 115th US House of Representatives

Usage

convertUSCensusCongress(nameOnly = FALSE)

Arguments

nameOnly

logical specifying whether to only return the name without creating the file

Value

Name of the dataset being created.

Details

A US congressional district shapefile is downloaded and converted to a SpatialPolygonsDataFrame with additional columns of data. The resulting file will be created in the spatial data directory which is set with setSpatialDataDir().

References

https://www.census.gov/geo/maps-data/data/cbf/cbf_cds.html

See Also

setSpatialDataDir